@@ -12,9 +12,3 @@
  */
 
 #undef crc32
-
-///  readbitmap - read bitmap
-extern void readbitmap(char* device, image_head image_hdr, unsigned long* bitmap, int pui);
-
-/// read super block and write to image head
-extern void initial_image_hdr(char* device, image_head* image_hdr);
